@@ -32,8 +32,7 @@ SELECTION_EMOJIS = collections.OrderedDict(
 
 @client.event
 async def on_ready():
-    """Login success informative log
-    """
+    """Login success informative log."""
     logger.info(f"Logged in as {client.user}")
 
 
@@ -50,19 +49,10 @@ async def on_message(message):
     if message.content.lower().startswith("krcg "):
         content = message.content[5:]
         logger.info(f"Received: {content}")
-        # when waiting for a user choice for card name completion,
-        # do nothing on wrong answers (maybe the user is trying another card text)
-        try:
-            content = client.COMPLETION_WAITING[message.author][int(content) - 1]
-        except (ValueError, TypeError, IndexError, KeyError):
-            pass
         # initial message handling. If multiple cards match, candidates are returned
         # and stored to the COMPLETION_WAITING map
         response = handle_message(content)
         candidates = response.pop("candidates", [])
-        if candidates:
-            logging.warning(f"53: {candidates}")
-            client.COMPLETION_WAITING[message.author] = candidates
         response = await message.channel.send(**response)
         # If they are candidates, add response reactions in the form of
         # square numbers emoji
@@ -78,12 +68,11 @@ async def on_message(message):
 
         while candidates:
             try:
-                reaction, user = await client.wait_for(
+                reaction, _user = await client.wait_for(
                     "reaction_add", timeout=30, check=check
                 )
             except asyncio.TimeoutError:
                 candidates = []
-                del client.COMPLETION_WAITING[message.author]
                 # try to clear reactions if the "message management" permission is up
                 # (this is not the default setting for bots, it will likely fail)
                 try:
@@ -94,11 +83,13 @@ async def on_message(message):
             else:
                 content = candidates[SELECTION_EMOJIS[reaction.emoji] - 1]
                 try:
-                    await response.edit(**handle_message(content))
+                    await response.edit(**handle_message(content, completion=False))
                 # this should not fail: bots can modify their messages
                 except discord.Forbidden:
                     logging.warning("Missing edit message permission")
-                    await message.channel.send(**handle_message(content))
+                    await message.channel.send(
+                        **handle_message(content, completion=False)
+                    )
 
 
 #: Response embed color depends on card type / clan
@@ -157,7 +148,7 @@ COLOR_MAP = {
 }
 
 
-def handle_message(message):
+def handle_message(message, completion=True):
     """Message handling
 
     Args:
@@ -173,21 +164,17 @@ def handle_message(message):
         message = int(message)
     except ValueError:
         pass
-    # use completion if no card is found
-    # all branches return in this conditional block
-    if message not in vtes.VTES:
+    # Use completion by default
+    if completion:
         try:
             candidates = vtes.VTES.complete(message)
-        # Ignore int messages, they can be wrong card IDs
-        # or (most likely) candidates selection for previous message that were
-        # out of range or not sent by author
         except AttributeError:
             candidates = []
         if len(candidates) == 1:
             message = candidates[0]
-        elif len(candidates) > 10:
+        elif len(candidates) > 10 and message not in vtes.VTES:
             return {"content": "Too many candidates, try a more complete card name."}
-        elif len(candidates):
+        elif 0 < len(candidates) <= 10:
             embed = {
                 "type": "rich",
                 "title": "What card did you mean ?",
@@ -195,7 +182,7 @@ def handle_message(message):
                 "description": "\n".join(
                     f"{i}: {card}" for i, card in enumerate(candidates, 1)
                 ),
-                "footer": {"text": 'Click a number or answer with one (eg. "krcg 1")'},
+                "footer": {"text": "Click a number as reaction."},
             }
             logger.info(embed)
             return {
@@ -203,8 +190,9 @@ def handle_message(message):
                 "embed": discord.Embed.from_dict(embed),
                 "candidates": candidates,
             }
-        else:
-            return {"content": "No card match"}
+    # Fuzzy match and known abbreviations only if completion did not help
+    if message not in vtes.VTES:
+        return {"content": "No card match"}
     # card is found, build fields
     card = vtes.VTES.normalized(vtes.VTES[message])
     card_type = "/".join(card["Type"])
@@ -252,7 +240,7 @@ def handle_message(message):
     )
     # build rulings field
     # if need be use the footer to indicate there are more of them available
-    footer = ""
+    footer = "Click the title to submit new rulings or rulings corrections"
     if card.get("Banned") or card.get("Rulings"):
         rulings = ""
         if card.get("Banned"):
@@ -270,7 +258,7 @@ def handle_message(message):
             # make sure we have the room for 3 dots
             if len(rulings) + len(ruling) > 1021:
                 rulings += "..."
-                footer += "More rulings available, click the title to see them."
+                footer = "More rulings available, click the title to see them"
                 break
             rulings += f"- {ruling}\n"
         fields.append({"name": "Rulings", "value": rulings, "inline": False})
